<?php

namespace App\Http\Controllers;

use App\Models\Advertisement;
use Illuminate\Http\Request;

class AdvertisementController extends Controller
{
    public function advertisements(){
        $advertisements = Advertisement::orderBy('id', 'desc')->paginate(15);
        return view('backend.ads.index', compact('advertisements'));
    }

    public function create() {
        return view('backend.ads.create');
    }

    public function store(Request $request) {
        // Validate the input
        $request->validate([
            'title' => 'required|string|max:255',
            'type' => 'required|in:adsense,custom',
            'adsense_code' => 'nullable|required_if:type,adsense',
            'custom_image' => 'nullable|required_if:type,custom|image|mimes:jpeg,png,jpg,gif|max:2048',
            'custom_link' => 'nullable|required_if:type,custom',
            'custom_html' => 'nullable',
            'start_date' => 'nullable|date',
            'end_date' => 'nullable|date|after_or_equal:start_date',
        ]);

        // Handle file upload for custom ads
        $imageName = null;

        if ($request->hasFile('custom_image')) {
            $imageName = 'ad-' . time() . '.' . $request->file('custom_image')->extension();
            $request->file('custom_image')->move(public_path('images/ads'), $imageName); // Move to 'public/images/ads'
        }

        // Store the ad
        Advertisement::create([
            'title' => $request->title,
            'type' => $request->type,
            'adsense_code' => $request->adsense_code,
            'custom_image' => $imageName,
            'custom_link' => $request->custom_link,
            'custom_html' => $request->custom_html,
            'status' => $request->status ?? 'active',
            'position' => $request->position,
            'start_date' => $request->start_date,
            'end_date' => $request->end_date,
        ]);

        return redirect()->route('admin.advertisements')->with('success', 'Advertisement created successfully!');
    }

    public function edit($id)
    {
        $advertisement = Advertisement::findOrFail($id);
        return view('backend.ads.edit', compact('advertisement'));
    }

    public function update(Request $request)
    {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {

            $advertisement = Advertisement::findOrFail($request->id);

            // Validate the input
            $request->validate([
                'title' => 'required|string|max:255',
                'type' => 'required|in:adsense,custom',
            ]);

            // Handle file upload for custom ads
            $imageName = $advertisement->custom_image;

            if ($request->hasFile('custom_image')) {
                // Delete the old image if it exists
                if ($advertisement->custom_image) {
                    unlink(public_path('images/ads/' . $advertisement->custom_image));
                }

                $imageName = 'ad-' . time() . '.' . $request->file('custom_image')->extension();
                $request->file('custom_image')->move(public_path('images/ads'), $imageName); // Move to 'public/images/ads'
            }

            // Update the ad
            $advertisement->update([
                'title' => $request->title,
                'type' => $request->type,
                'adsense_code' => $request->adsense_code,
                'custom_image' => $imageName,
                'custom_link' => $request->custom_link,
                'custom_html' => $request->custom_html,
                'status' => $request->status ?? 'active',
                'position' => $request->position,
                'start_date' => $request->start_date,
                'end_date' => $request->end_date,
            ]);

            return redirect()->route('admin.advertisements')->with('success', 'Advertisement updated successfully!');
        }
    }

    public function delete($id) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $advertisement = Advertisement::findOrFail($id);

            // Check if the custom image exists and delete it
            if ($advertisement->custom_image) {
                $imagePath = public_path('images/ads/' . $advertisement->custom_image);

                // Check if the file exists before attempting to delete
                if (file_exists($imagePath)) {
                    unlink($imagePath);
                }
            }

            // Delete the advertisement record from the database
            $advertisement->delete();

            return redirect()->route('admin.advertisements')->with('success', 'Advertisement deleted successfully!');
        }
    }

    public function toggleStatus(Request $request) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $advertisement = Advertisement::findOrFail($request->id);
            $advertisement->status = $request->is_active;
            $advertisement->save();

            return response()->json(['success' => true]);
        }
    }


}
