<?php

namespace App\Http\Controllers;

use App\Mail\NewsletterMail;
use App\Models\BusinessSettings;
use App\Models\Menus;
use App\Models\Subscriber;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;

class BusinessSettingsController extends Controller
{
    public function ServerInfo() {
        return view('backend.system.server-status');
    }

    public function HeaderSettings() {
        $menus = Menus::orderBy('id', 'desc')->get();
        $selectedMenu = BusinessSettings::where('key', 'main_menu')->first()->value;
        $search = BusinessSettings::where('key', 'header_search')->first();
        $login = BusinessSettings::where('key', 'header_login')->first();
        return view('backend.website-settings.header-setting', compact('menus', 'selectedMenu', 'search', 'login'));
    }

    public function UpdateHeaderSettings(Request $request) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            // Validate the request
            $request->validate([
                'menu' => 'required|integer',
                'search' => 'required|in:0,1',
                'login' => 'required|in:0,1',
            ]);

            // Save or update settings
            $this->updateOrCreateSetting('main_menu', $request->menu);
            $this->updateOrCreateSetting('header_search', $request->search);
            $this->updateOrCreateSetting('header_login', $request->login);

            return redirect()->back()->with('success', 'Header settings updated successfully.');
        }
    }

    public function GlobalSettings(){
        $settings = BusinessSettings::pluck('value', 'key')->toArray();
        $adsTxtPath = public_path('ads.txt');
        $adsTxt = File::exists($adsTxtPath) ? File::get($adsTxtPath) : '';
        return view('backend.website-settings.global-setting', compact('settings', 'adsTxt'));
    }

    public function UpdateGlobalSettings(Request $request) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            // Save or update settings
            $this->updateOrCreateSetting('website_name', $request->website_name);
            $this->updateOrCreateSetting('website_description', $request->werbsite_description);
            $this->updateOrCreateSetting('contact_email', $request->contact_email);
            $this->updateOrCreateSetting('website_meta_title', $request->website_meta_title);
            $this->updateOrCreateSetting('website_meta_description', $request->website_meta_description);
            $this->updateOrCreateSetting('website_tags', $request->website_tags);
            $this->updateOrCreateSetting('gamepix_sid', $request->gamepix_sid);
            $this->updateOrCreateSetting('website_tagline', $request->website_tagline);

            // Handle image upload for the website logo
            if ($request->hasFile('image')) {
                $imageName = time() . '.' . $request->image->extension();
                $request->image->move(public_path('images/logos'), $imageName);
                $this->updateOrCreateSetting('website_logo', $imageName);
            }

            // Handle image upload for the website favicon
            if ($request->hasFile('banner')) {
                $faviconPath = 'fav' . time() . '.' . $request->banner->extension();
                $request->banner->move(public_path('images/favicons'), $faviconPath);
                $this->updateOrCreateSetting('website_favicon', $faviconPath);
            }

            return redirect()->back()->with('success', 'Global settings updated successfully.');
        }
    }



    protected function updateOrCreateSetting($key, $value)
    {
        BusinessSettings::updateOrCreate(
            ['key' => $key], // Find setting by key
            ['value' => $value] // Update or insert the value
        );
    }

    public function SEOSettingsUpdate(Request $request){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            // Save Google Analytics tags in the BusinessSettings table
            $businessSetting = BusinessSettings::where('key', 'google_analytics')->first();
            if ($businessSetting) {
                $businessSetting->value = $request->input('google-analytics');
                $businessSetting->save();
            } else {
                BusinessSettings::create([
                    'key' => 'google_analytics',
                    'value' => $request->input('google-analytics'),
                ]);
            }

            // Save Ads.txt content in public/ads.txt file
            $adsTxtPath = public_path('ads.txt');
            File::put($adsTxtPath, $request->input('adstxt'));

            // Redirect with a success message
            return redirect()->back()->with('success', 'SEO settings updated successfully.');
        }
    }

    public function SocialSettingsUpdate(Request $request){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            // Save or update social media settings
            $this->updateOrCreateSetting('facebook_link', $request->facebook_link);
            $this->updateOrCreateSetting('twitter_link', $request->twitter_link);
            $this->updateOrCreateSetting('instagram_link', $request->instagram_link);
            $this->updateOrCreateSetting('youtube_link', $request->youtube_link);

            return redirect()->back()->with('success', 'Social media settings updated successfully.');
        }
    }

    public function MobileAppSettings() {
        return view('backend.mobile.api-information');
    }

    public function SmtpSettings(){
        return view('backend.website-settings.smtp-settings');
    }

    public function SmtpSettingsUpdate(Request $request){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            // Array of key-value pairs to update the .env file
            $envData = [
                'MAIL_MAILER' => $request->smtp_type,
                'MAIL_HOST' => $request->mail_host,
                'MAIL_PORT' => $request->mail_port,
                'MAIL_USERNAME' => $request->mail_username,
                'MAIL_PASSWORD' => $request->mail_password,
                'MAIL_ENCRYPTION' => $request->mail_encryption,
                'MAIL_FROM_ADDRESS' => $request->mail_from_address,
                'MAIL_FROM_NAME' => $request->mail_from_name,
            ];

            // Call the function to set and update the .env file
            $this->updateEnv($envData);

            // Return back with success message
            return back()->with('success', 'SMTP settings updated successfully!');
        }
    }

    protected function updateEnv($data)
    {
        $envFile = base_path('.env');
        $str = File::get($envFile);

        foreach ($data as $envKey => $envValue) {
            $keyPosition = strpos($str, "{$envKey}=");
            $endOfLinePosition = strpos($str, "\n", $keyPosition);
            $oldLine = substr($str, $keyPosition, $endOfLinePosition - $keyPosition);

            // Update with the new value or add it if it doesn't exist
            if ($keyPosition && $oldLine) {
                $str = str_replace($oldLine, "{$envKey}=\"{$envValue}\"", $str);
            } else {
                $str .= "{$envKey}=\"{$envValue}\"\n";
            }
        }

        // Write the updated .env file
        File::put($envFile, $str);
    }

    public function sendTestEmail(Request $request)
    {
        $request->validate([
            'email' => 'required|email',
        ]);

        $email = $request->input('email');

        try {
            // Send a test email
            Mail::raw('This is a test email to verify your SMTP configuration.', function ($message) use ($email) {
                $website_name = BusinessSettings::where('key', 'website_name')->first()->value;
                $message->to($email)->subject('SMTP Configuration test for ' . $website_name);
            });

            return back()->with('success', 'Test email sent successfully to ' . $email);
        } catch (\Exception $e) {
            // Catch and handle the error
            return back()->with('error', 'Failed to send test email: ' . $e->getMessage());
        }
    }

    public function NewsLetters() {
        $subscribers = Subscriber::where('status', 1)->get();
            $users = User::where('role', 'user')->where('status', 1)->get();
            return view('backend.newsletter.create', compact('subscribers', 'users'));
        }

    public function sendNewletter(Request $request) {

        $userEmails = $request->input('email_users', []);
        $subscriberEmails = $request->input('email_subscribers', []);

        $userEmails = is_array($userEmails) ? $userEmails : [$userEmails];
        $subscriberEmails = is_array($subscriberEmails) ? $subscriberEmails : [$subscriberEmails];

        $emails = array_merge($userEmails, $subscriberEmails);

        $subject = $request->input('newsletter_subject');
        $htmlContent = $request->input('description');
        $textContent = strip_tags($htmlContent);

        foreach ($emails as $email) {
            Mail::to($email)->send(new NewsletterMail($subject, $htmlContent, $textContent));
        }
        return redirect()->back()->with('success', 'Newsletter sent successfully!');
    }


    public function setTheme(Request $request) {
        $theme = $request->input('theme');
        Session::put('theme', $theme);
        $this->updateOrCreateSetting('theme', $theme);

        return response()->json(['success' => true]);
    }


}
