<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Languages;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;

class CategoryController extends Controller
{
    public function categories(){
        if (Auth::user()->role == 'admin') {
            $categories = Category::orderBy('id', 'desc')->paginate(15);
            return view('backend.category.index', compact('categories'));
        } else {
            abort(403, 'Unauthorized action.');
        }

    }

    public function create(){
        $parentCategory = Category::where('parent_id', null)->get();
        $languages = Languages::where('status', 1)->get();
        return view('backend.category.create', compact('parentCategory', 'languages'));
    }

    public function store(Request $request)
    {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            // Create a new Category instance
            $category = new Category();
            $category->name = $request['name'];
            $category->slug = Str::slug($request['name']);
            $category->description = $request['description'] ?? null;
            $category->parent_id = $request['parent_id'] ?? null;

            // Handle the image upload
            if ($request->hasFile('image')) {
                $imageName = time() . '.' . $request->image->extension();
                $request->image->move(public_path('images/categories'), $imageName);
                $category->image = $imageName;
            }

            // Save the category
            $category->save();

            // Redirect back with a success message
            return redirect()->route('admin.categories')->with('success', 'Category created successfully.');
        }

    }

    public function toggleStatus(Request $request) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $category = Category::findOrFail($request->id);
            $category->is_active = $request->is_active;
            $category->save();

            return response()->json(['success' => true, 'message' => 'Status updated successfully.']);
        }
    }

    public function toggleStatusHomepage(Request $request) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $category = Category::findOrFail($request->id);
            $category->is_home_page = $request->is_home_page;
            $category->save();

            return response()->json(['success' => true, 'message' => $category->name.' Category Status updated successfully.']);
        }
    }

    public function edit($id)
    {
        $category = Category::findOrFail($id);
        $parentCategory = Category::where('parent_id', null)->get();
        $languages = Languages::where('status', 1)->get();

        // Fetch translations by language code
        $translations = $category->translations->keyBy('locale'); // Key translations by locale instead of language_code
        return view('backend.category.edit', compact('category', 'parentCategory', 'languages', 'translations'));
    }


    public function update(Request $request)
    {
        if (env('DEMO_MODE') == 'off') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        }

        // Validate the category ID and name field (required for the category)
        $request->validate([
            'name' => 'required|string|max:255',  // For default category name
            'id' => 'required|exists:categories,id',
        ]);

        // Find the category by ID
        $category = Category::findOrFail($request->id);

        // Update the default (English) category values
        $category->name = $request->input('name');
        $category->slug = Str::slug($request->input('name'));
        $category->description = $request->input('description', null);
        $category->parent_id = $request->input('parent_id', null);

        // Handle the image upload if provided
        if ($request->hasFile('image')) {
            $imageName = time() . '.' . $request->image->extension();
            $request->image->move(public_path('images/categories'), $imageName);
            $category->image = $imageName;
        }

        // Save the category (this will save the default name)
        $category->save();

        // Handle translations for other languages
        if ($request->has('translations')) {
            foreach ($request->translations as $languageCode => $translationData) {
                $category->translations()->updateOrCreate(
                    ['locale' => $languageCode, 'category_id' => $category->id],  // Add category_id explicitly
                    [
                        'name' => $translationData['name'] ?? '',
                        'description' => $translationData['description'] ?? '',
                    ]
                );
            }
        }

        // Redirect with success message
        return redirect()->route('admin.categories')->with('success', 'Category updated successfully.');
    }

    public function delete($id){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $category = Category::findOrFail($id);
            $category->delete();
            return redirect()->route('admin.categories')->with('success', 'Category deleted successfully.');
        }
    }

}
