<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\CountryVisit;
use Illuminate\Http\Request;
use App\Models\Game;
use App\Models\GameReaction;
use App\Models\PageView;
use App\Models\User;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Str;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class DashboardController extends Controller
{
    public function Dashboard() {
        if (Auth::user()->role === 'admin') {
            $totalGames = Game::count();
            $totalCategories = Category::count();
            $totalUsers = User::where('role', 'user')->count();
            $totalLikes = GameReaction::where('like', 1)->count();
            $popularGames = Game::orderBy('views', 'desc')->take(10)->get();
            $mostLikedGames = Game::withCount(['reactions' => function ($query) {
                $query->where('like', true); // Counting only the 'like' reactions
            }])
            ->orderBy('reactions_count', 'desc') // Ordering by the number of likes
            ->take(8) // Limiting the number of results, adjust as needed
            ->get();

            $apiUrl = 'https://gamemonetize.com/feed.php?format=0&num=20&page=1';

            if (!empty($gameOrder)) {
                $apiUrl .= '&order=' . $gameOrder;
            }

            // Make API request to fetch the games
            $response = Http::get($apiUrl);

            $gametoAdd = json_decode($response, true);

            $recentGames = Game::orderBy('created_at', 'desc')->take(9)->get();

            $todayAddedGames = number_format(Game::whereDate('created_at', Carbon::today())->count());

            $totalVisitors = PageView::count();
            $uniqueVisitors = PageView::distinct('ip_address')->count();
            $totalPageViews = PageView::count();
            $monthlyPageViews = PageView::where('created_at', '>=', Carbon::now()->startOfMonth())->count();
            // Get visitor count per country
            $countryVisits = DB::table('country_visits')
                            ->select('country_code', DB::raw('COUNT(*) as visits'))
                            ->groupBy('country_code')
                            ->get();


            return view('backend.dashboard.index', compact(
                'totalGames', 'totalCategories', 'totalUsers', 'totalLikes', 'popularGames',
                'mostLikedGames', 'gametoAdd', 'recentGames', 'todayAddedGames','totalVisitors',
                'uniqueVisitors','totalPageViews','monthlyPageViews', 'countryVisits'
            ));
        }

        abort(403, 'Unauthorized action.');

    }

    public function AddDash(Request $request) {
        // Check if the request contains multiple games
        if ($request->has('games')) {
            foreach ($request->games as $gameData) {
                // Normalize the category
                $categoryMappings = [
                    'hypercasual' => 'hyper-casual',
                    'hyper-casual' => 'hyper-casual',
                    'car race' => 'car racing',
                    'car racing' => 'car racing',
                    'shooter' => 'shooting',
                    'shooting' => 'shooting',
                    'games-for-girls' => 'girls',
                    'girls' => 'girls',
                ];

                $requestedCategory = Str::slug($gameData['category']);
                $normalizedCategory = $categoryMappings[$requestedCategory] ?? $gameData['category'];

                // Check if the category exists or create a new one
                $category = Category::firstOrCreate(
                    ['slug' => Str::slug($normalizedCategory)],
                    ['name' => $normalizedCategory]
                );

                // Check if the game already exists by a unique field (e.g., name or URL)
                $existingGame = Game::where('name', $gameData['title'])
                                    ->orWhere('game_url', $gameData['url'])
                                    ->first();

                if (!$existingGame) {
                    // Download images for the game
                    $imagePath = $this->downloadImage($gameData['image'], 'icons');
                    $bannerPath = $this->downloadImage($gameData['image'], 'banner');

                    // Create a new game record if not found
                    Game::create([
                        'category_id' => $category->id,
                        'name' => $gameData['title'],
                        'description' => $gameData['description'],
                        'image' => $imagePath, // Save the image path
                        'banner' => $bannerPath, // Save the banner path
                        'slug' => Str::slug($gameData['title']),
                        'game_url' => $gameData['url'],
                        'meta_title' => $gameData['title'],
                        'meta_description' => $gameData['description'],
                        'tags' => $gameData['tags']
                    ]);
                } else {
                    // Optionally, handle the case where the game already exists
                    // You could log it, update it, or ignore it, depending on your needs
                }
            }

            return response()->json(['success' => true, 'message' => 'Games added successfully.']);
        }

        // If no games array is provided, return an error response
        return response()->json(['success' => false, 'message' => 'No games provided.']);
    }

    private function downloadImage($url, $folder)
    {
        $cleanUrl = strtok($url, '?'); // Remove query parameters

        // Get the image extension and name
        $fileExtension = pathinfo($cleanUrl, PATHINFO_EXTENSION);
        $imageName = time() . '.' . $fileExtension;

        // Define the image path where it will be stored
        $imagePath = public_path('images/games/' . $folder . '/' . $imageName);

        // Create the folder if it doesn't exist
        if (!file_exists(public_path('images/games/' . $folder))) {
            mkdir(public_path('images/games/' . $folder), 0775, true);
        }

        // Use cURL to download the image
        $ch = curl_init($cleanUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true); // Follow redirects
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // Skip SSL verification (optional)

        $imageData = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);

        if ($httpCode == 200 && $imageData) {
            file_put_contents($imagePath, $imageData);
        } else {
            return null; // Handle error case
        }

        curl_close($ch);

        return $imageName; // Return relative path
    }

    public function storeVisitData() {
        $location = getUserCountry(); // Get country data via IPinfo API

        if ($location) {
            CountryVisit::updateOrCreate(
                ['country_code' => $location['country']],
                ['latitude' => $location['latitude'], 'longitude' => $location['longitude']]
            );
        }
    }

    public function saveLocation(Request $request)
    {
        $request->validate([
            'country_code' => 'required|string|max:3',
            'latitude' => 'required|numeric',
            'longitude' => 'required|numeric',
        ]);

        // Save location data to the database
        DB::table('country_visits')->insert([
            'country_code' => $request->country_code,
            'latitude' => $request->latitude,
            'longitude' => $request->longitude,
        ]);

        return response()->json(['message' => 'Location saved successfully']);
    }

    public function getLiveLocations()
    {
        // Get the live user locations (you may filter based on recent visits or any condition)
        $liveLocations = CountryVisit::select('latitude', 'longitude', 'country_code')
                                     ->orderByDesc('created_at')
                                     ->limit(100)  // Limit number of live points if necessary
                                     ->get();

        return response()->json($liveLocations);
    }

    // DashboardController.php
    public function getCountryData()
    {
        $data = DB::table('country_visits')
            ->select('country_code', DB::raw('COUNT(*) as total_visitors'))
            ->groupBy('country_code')
            ->get();

        return response()->json($data);
    }


}
