<?php

namespace App\Http\Controllers;

use App\Models\BusinessSettings;
use App\Models\Languages;
use Illuminate\Http\Request;
use Mcamara\LaravelLocalization\Facades\LaravelLocalization;

class LanguagesController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $defaultLanguage = BusinessSettings::where('key', 'default_language')->first();
        $languages = Languages::all();
        return view('backend.languages.index', compact('languages', 'defaultLanguage'));
    }

    public function CreateLanguage(){
        $languages = LaravelLocalization::getSupportedLocales();
        return view('backend.languages.create', compact('languages'));
    }

    public function storeLanguage(Request $request){
        // Validate the input with custom error messages
        $validated = $request->validate([
            'name' => 'required|string|max:255',
            'code' => 'required|string|max:10|unique:languages,code',
            'app_lang_code' => 'required|string|max:10',
        ], [
            'code.unique' => 'The language code is already taken. Please choose another one.'
        ]);

        try {
            // Store the data if validation passes
            Languages::create([
                'name' => $request->name,
                'code' => $request->code,
                'app_lang_code' => $request->app_lang_code,
            ]);

            // Redirect back with success message
            return redirect()->route('admin.languages')->with('success', 'Language added successfully!');

        } catch (\Exception $e) {
            // If there's an error, display the error message
            return redirect()->back()->with('error', 'There was an issue adding the language: ' . $e->getMessage());
        }
    }

    public function StoreDefaultLanguage(Request $request){
        // Validate the incoming request
        $request->validate([
            'default_language' => 'required|exists:languages,code', // Ensure the language exists in the languages table
        ]);

        // Find or create the BusinessSetting for default language
        $defaultLanguageSetting = BusinessSettings::where('key', 'default_language')->first();

        // If the setting does not exist, create it, otherwise update it
        if ($defaultLanguageSetting) {
            $defaultLanguageSetting->value = $request->default_language;
            $defaultLanguageSetting->save();
        } else {
            BusinessSettings::create([
                'key' => 'default_language',
                'value' => $request->default_language
            ]);
        }

        // Redirect back with a success message
        return redirect()->back()->with('success', 'Default language updated successfully.');
    }

    public function editLanguage($id){
        $language = Languages::findOrFail($id);
        $languages = LaravelLocalization::getSupportedLocales();
        return view('backend.languages.edit', compact('language', 'languages'));
    }

    public function updateLanguage(Request $request){
        $language = Languages::findOrFail($request->id);

        // Validate the input with custom error messages
        $validated = $request->validate([
            'name' => 'required|string|max:255',
            'code' => 'required|string|max:10|unique:languages,code',
            'app_lang_code' => 'required|string|max:10',
        ], [
            'code.unique' => 'The language code is already taken. Please choose another one.'
        ]);

        try {
            // Update the data if validation passes
            $language->update([
                'name' => $request->name,
                'code' => $request->code,
                'app_lang_code' => $request->app_lang_code,
            ]);

            // Redirect back with success message
            return redirect()->route('admin.languages')->with('success', 'Language updated successfully!');

        } catch (\Exception $e) {
            // If there's an error, display the error message
            return redirect()->back()->with('error', 'There was an issue updating the language: ' . $e->getMessage());
        }
    }

    public function toggleStatus(Request $request){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $category = Languages::findOrFail($request->id);
            $category->status = $request->status;
            $category->save();

            return response()->json(['success' => true]);
        }
    }

    public function deleteLanguage(Request $request){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $language = Languages::findOrFail($request->id);
            $language->delete();

            return redirect()->back()->with('success', 'Language deleted successfully!');
        }
    }
}
